pub struct Repository {
pub url: String,
pub name: String,
pub path: PathBuf,
pub content: Option<HashMap<String, String>>,
}Fields
url: Stringname: Stringpath: PathBufcontent: Option<HashMap<String, String>>Implementations
Sourceimpl Repository
impl Repository
Sourcepub fn new(base_download_dir: &Path, repo_url: &str) -> Self
pub fn new(base_download_dir: &Path, repo_url: &str) -> Self
Creates a new Repository instance from a remote GitHub URL.
Sourcepub fn from_local_path(local_path: &Path) -> Self
pub fn from_local_path(local_path: &Path) -> Self
Creates a new Repository instance from a local file system path.
pub fn has_content(&self) -> bool